# -*- coding: utf-8 -*-
"""
PAGO documentation build configuration file
"""
# , created by
# sphinx-quickstart on Wed Jul 29 14:31:09 2015
#
# This file is execfile()d with the current directory set to its
# containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

import sys
import os
import shlex

import matplotlib
matplotlib.use('Agg')

CURDIR = os.path.abspath(os.path.dirname(__file__))
version_file = os.path.abspath("{0}/../../../VERSION".format(CURDIR))

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
sys.path.insert(0, os.path.abspath('../../..'))
sys.path.insert(0, os.path.abspath('../../docs/manuals'))

import pypago
from mpl_toolkits.basemap import pyproj  # an attempt to link to doc of mpl_toolkits.basemap.pyproj.Geod
# -- General configuration ------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
# .. todo:: retrieve minimal sphinx version from setup.py but only major.minor
# here
needs_sphinx = '1.3'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = ['sphinx.ext.autodoc',
              'sphinx.ext.doctest',
              'sphinx.ext.autosummary',
              'sphinx.ext.intersphinx',
              'sphinx.ext.todo',
              'sphinx.ext.coverage',
              'sphinx.ext.mathjax',
              'sphinx.ext.ifconfig',
              #'matplotlib.sphinxext.mathmpl',
              'matplotlib.sphinxext.only_directives',
              'matplotlib.sphinxext.plot_directive',
              'sphinx.ext.viewcode', 
              'sphinxcontrib.bibtex',
              'IPython.sphinxext.ipython_directive',
              'IPython.sphinxext.ipython_console_highlighting'
              ]


# autodoc_default_flags = ['members']
# autodoc_default_flags = ['members', 'undoc-members', 'special-members', 'private-members', 'inherited-members']
# autodoc_default_flags = ['members', 'undoc-members', 'special-members', 'private-members']
autodoc_default_flags = ['members', 'undoc-members', 'private-members']
autosummary_generate = True

numfig = True

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
# source_suffix = ['.rst', '.md']
source_suffix = '.rst'

# The encoding of source files.
# source_encoding = 'utf-8-sig'

# The master toctree document.
master_doc = 'index'

# General information about the project.
project = u'PAGO' # ++ setup
copyright = u'2016, CNRS' # ++ setup
author_email = pypago.__author_email__ # ++ setup

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The short X.Y version.

with open(version_file) as fd:
    version = fd.read().strip()
# The full version, including alpha/beta/rc tags.
release = version

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = None

# There are two options for replacing |today|: either, you set today to some
# non-false value, then it is used:
# today = ''
# Else, today_fmt is used as the format for a strftime call.
# today_fmt = '%B %d, %Y'

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
exclude_patterns = ['_build', 'prolog.rst', '*.txt']

# Included at the beginning of every source file that is read.
with open('prolog.rst', 'r') as pr:
    rst_prolog = pr.read()

rst_prolog

# The reST default role (used for this markup: `text`) to use for all
# documents.
# default_role = None

# If true, '()' will be appended to :func: etc. cross-reference text.
# add_function_parentheses = True

# If true, the current module name will be prepended to all description
# unit titles (such as .. function::).
add_module_names = False

# If true, sectionauthor and moduleauthor directives will be shown in the
# output. They are ignored by default.
# show_authors = False

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# A list of ignored prefixes for module index sorting.
# modindex_common_prefix = []

# If true, keep warnings as "system message" paragraphs in the built documents.
# keep_warnings = False


# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = True

# -- Options for HTML output ----------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
html_theme = 'sphinxdoc'

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
# html_theme_options = {}

# Add any paths that contain custom themes here, relative to this directory.
# html_theme_path = []

# The name for this set of Sphinx documents.  If None, it defaults to
# "<project> v<release> documentation".
# html_title = None

# A shorter title for the navigation bar.  Default is the same as html_title.
# html_short_title = None


# The name of an image file (relative to this directory) to place at the top
# of the sidebar.
html_logo = "_static/pago_background.jpg"

# The name of an image file (within the static path) to use as favicon of the
# docs.  This file should be a Windows icon file (.ico) being 16x16 or 32x32
# pixels large.
html_favicon = "_static/pago.ico"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

# Add any extra paths that contain custom files (such as robots.txt or
# .htaccess) here, relative to this directory. These files are copied
# directly to the root of the documentation.
# html_extra_path = []

# If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
# using the given strftime format.
html_last_updated_fmt = '%Y%m%d'


# If true, SmartyPants will be used to convert quotes and dashes to
# typographically correct entities.
# html_use_smartypants = True

# Custom sidebar templates, maps document names to template names.
html_sidebars = {'**': ['localtoc.html',
                        'searchbox.html',
                        'recentupdates.html',
                        'relatedlinks.html']}

# Additional templates that should be rendered to pages, maps page names to
# template names.
html_additional_pages = {'index': 'index.html'}

# If false, no module index is generated.
# html_domain_indices = True

# If false, no index is generated.
html_use_index = True

# If true, the index is split into individual pages for each letter.
# html_split_index = False

# If true, links to the reST sources are added to the pages.
# html_show_sourcelink = True

# If true, "Created using Sphinx" is shown in the HTML footer. Default is True.
html_show_sphinx = True

# If true, "(C) Copyright ..." is shown in the HTML footer. Default is True.
html_show_copyright = True

# If true, an OpenSearch description file will be output, and all pages will
# contain a <link> tag referring to it.  The value of this option must be the
# base URL from which the finished HTML is served.
# html_use_opensearch = ''

# This is the file name suffix for HTML files (e.g. ".xhtml").
# html_file_suffix = None

# Language to be used for generating the HTML full-text search index.
# Sphinx supports the following languages:
#   'da', 'de', 'en', 'es', 'fi', 'fr', 'hu', 'it', 'ja'
#   'nl', 'no', 'pt', 'ro', 'ru', 'sv', 'tr'
# html_search_language = 'en'

# A dictionary with options for the search language support, empty by default.
# Now only 'ja' uses this config value
# html_search_options = {'type': 'default'}


# The name of a javascript file (relative to the configuration directory) that
# implements a search results scorer. If empty, the default will be used.
# html_search_scorer = 'scorer.js'

# Output file base name for HTML help builder.
htmlhelp_basename = 'PAGOdoc'

# -- Options for LaTeX output ---------------------------------------------

latex_elements = {'classoptions': ',openany,oneside',
                  'babel': '\\usepackage[english]{babel}',
                  # The paper size ('letterpaper' or 'a4paper').
                  'papersize': 'a4paper',
                  # The font size ('10pt', '11pt' or '12pt').
                  'pointsize': '12pt',
                  # Additional stuff for the LaTeX preamble.
                  'preamble': '\\usepackage{float}',
                  'figure_align': 'H'}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title,
#  author, documentclass [howto/manual]).
latex_documents = [
    ('index', 'PAGO.tex', u'PAGO Documentation', u'PAGO team', 'manual'),
]

# The name of an image file (relative to this directory) to place at the top of
# the title page.
latex_logo = html_logo

# For "manual" documents, if this is true, then toplevel headings are parts,
# not chapters.
# latex_use_parts = False

# If true, show page references after internal links.
# latex_show_pagerefs = False

# If true, show URL addresses after external links.
# latex_show_urls = False

# Documents to append as an appendix to all manuals.
# latex_appendices = []

# If false, no module index is generated.
# latex_domain_indices = True


# -- Options for manual page output ---------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    ('index', 'pago', u'PAGO Documentation',
     [u'PAGO team'], 1)
]

# If true, show URL addresses after external links.
# man_show_urls = False


# -- Options for Texinfo output -------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    ('index', 'PAGO', u'PAGO Documentation', 'PAGO team', 'PAGO',
     'On line description of project.', 'Miscellaneous'),
]

# Documents to append as an appendix to all manuals.
# texinfo_appendices = []

# If false, no module index is generated.
# texinfo_domain_indices = True

# How to display URL addresses: 'footnote', 'no', or 'inline'.
# texinfo_show_urls = 'footnote'

# If true, do not generate a @detailmenu in the "Top" node's menu.
# texinfo_no_detailmenu = False

# Example configuration for intersphinx: refer to the Python standard library.
intersphinx_mapping = {'python': ('https://docs.python.org/2/', None),
                       'scipy': ('http://docs.scipy.org/doc/scipy/reference/', None),
                       'numpy': ('http://docs.scipy.org/doc/numpy/', None),
                       'matplotlib': ('http://matplotlib.org/', None),
                       'basemap': ('http://matplotlib.org/basemap/', None), }

# TIPS
# ====
#
# If network is down, we can still work in standalone mode by
# comment intersphinx_mapping setup. ++ intersphinx_mapping_cache limit
#
# TODO
# ====
#
# find a way to ue author_email in layout.html.
#
# This is not possible now because only sphinx defined variable are usable in
# this file
#
# see the list in http://sphinx-doc.org/templating.html
#
# master_doc should be contents or index ...
#
# reduce members to end-users modules
#
# solve mpl_toolkits intersphinx issue (cf. _distance.py)
#
# EVOLUTIONS
# ==========
#
# - fplod 20151030T160020Z guest-242.locean-ipsl.upmc.fr (Darwin)
#
#   * version from :file:`VERSION`
#
# - fplod 20151001T160918Z
#
#   * give up matlab extension
#
# - fplod 20150915T114230Z guest-242.locean-ipsl.upmc.fr (Darwin)
#
#   * produce todo
#
# - fplod 20150915T094634Z guest-242.locean-ipsl.upmc.fr (Darwin)
#
#   * add setup of usage of plot_directive (matplotlib extension)
#
# - fplod 20150821T095229Z guest-242.locean-ipsl.upmc.fr (Darwin)
#
#   * intersphinx_mapping key must be alphanumeric (so underscore
#     not allowed
#
# - fplod 20150819T130727Z guest-242.locean-ipsl.upmc.fr (Darwin)
#
#   * attempt to intersphinx to mpl_toolkits (intersphinx and import)
#   * add more members to scan first round on docstrings even for private and special modules
#   * update matplotlib URL for intersphinx)
#
# - fplod 20150806T164011Z guest-242.locean-ipsl.upmc.fr (Darwin)
#
#   * fix usage of _templates/index.html (and customize it)
#
# - fplod 20150806T095759Z guest-242.locean-ipsl.upmc.fr (Darwin)
#
#   * remove blank pages (a lot !) from PDF
#     thanks to
#     http://stackoverflow.com/questions/5422997/sphinx-docs-remove-blank-pages-from-generated-pdfs  # pylint: disable=line-too-long
#
# - fplod 20150806T082233Z guest-242.locean-ipsl.upmc.fr (Darwin)
#
#   * add supplemental material to the default sidebar
#     thanks to https://github.com/aws/aws-cli/tree/develop/doc/source
#
# - fplod 20150804T134549Z guest-242.locean-ipsl.upmc.fr (Darwin)
#
#   * add prolog
#
# - fplod 20150804T114556Z guest-242.locean-ipsl.upmc.fr (Darwin)
#
#   * join PAGO website files and PyPAGO documentation
#
# - fplod 20150803T112940Z guest-242.locean-ipsl.upmc.fr (Darwin)
#
#   * add main intersphinx
